@@ -2,13 +2,16 @@
 
 #include <stdint.h>
 #include <time.h>
-#include <stdio.h>
 #ifdef _WIN32
     #include <synchapi.h>
     #include <profileapi.h>
     #include <sysinfoapi.h>
+#elif defined(__HAIKU__)
+    #include <OS.h>
 #endif
 
+#include "common/arrayUtils.h"
+
 static inline double ffTimeGetTick(void) //In msec
 {
     #ifdef _WIN32
@@ -17,6 +20,8 @@ static inline double ffTimeGetTick(void) //In msec
         LARGE_INTEGER start;
         QueryPerformanceCounter(&start);
         return (double) start.QuadPart * 1000 / (double) frequency.QuadPart;
+    #elif defined(__HAIKU__)
+        return (double) system_time() / 1000.;
     #else
         struct timespec timeNow;
         clock_gettime(CLOCK_MONOTONIC, &timeNow);
@@ -30,6 +35,8 @@ static inline uint64_t ffTimeGetNow(void)
         uint64_t timeNow;
         GetSystemTimeAsFileTime((FILETIME*) &timeNow);
         return (timeNow - 116444736000000000ull) / 10000ull;
+    #elif defined(__HAIKU__)
+        return (uint64_t) real_time_clock_usecs() / 1000u;
     #else
         struct timespec timeNow;
         clock_gettime(CLOCK_REALTIME, &timeNow);
@@ -46,36 +53,20 @@ static inline void ffTimeSleep(uint32_t msec)
     #endif
 }
 
-#ifdef _WIN32
-    #pragma GCC diagnostic push
-    #pragma GCC diagnostic ignored "-Wformat"
-#endif
+// Not thread-safe
+const char* ffTimeToFullStr(uint64_t msec);
 
 // Not thread-safe
-static inline const char* ffTimeToFullStr(uint64_t msec)
-{
-    if (msec == 0) return "";
-    time_t tsec = (time_t) (msec / 1000);
-    const struct tm* tm = localtime(&tsec);
-
-    static char buf[32];
-    strftime(buf, __builtin_strlen("0000-00-00T00:00:00") + 1, "%FT%T", tm);
-    snprintf(buf + __builtin_strlen("0000-00-00T00:00:00"), __builtin_strlen(".000") + 1, ".%03u", (unsigned) (msec % 1000));
-    strftime(buf + __builtin_strlen("0000-00-00T00:00:00.000"), __builtin_strlen("+0000") + 1, "%z", tm);
-    return buf;
-}
+const char* ffTimeToShortStr(uint64_t msec);
 
 // Not thread-safe
-static inline const char* ffTimeToShortStr(uint64_t msec)
+const char* ffTimeToTimeStr(uint64_t msec);
+
+typedef struct FFTimeGetAgeResult
 {
-    if (msec == 0) return "";
-    time_t tsec = (time_t) (msec / 1000);
+    uint32_t years;
+    uint32_t daysOfYear;
+    double yearsFraction;
+} FFTimeGetAgeResult;
 
-    static char buf[32];
-    strftime(buf, sizeof(buf), "%F %T", localtime(&tsec));
-    return buf;
-}
-
-#ifdef _WIN32
-    #pragma GCC diagnostic pop
-#endif
+FFTimeGetAgeResult ffTimeGetAge(uint64_t birthMs, uint64_t nowMs);
