@@ -1,6 +1,6 @@
 #include "board.h"
 #include "common/settings.h"
-#include "util/smbiosHelper.h"
+#include "common/smbiosHelper.h"
 
 const char* ffDetectBoard(FFBoardResult* result)
 {
