@@ -2,8 +2,8 @@
 
 #include "adl.h"
 #include "common/library.h"
-#include "util/mallocHelper.h"
-#include "util/debug.h"
+#include "common/mallocHelper.h"
+#include "common/debug.h"
 
 // Helper function to convert ADL status code to string
 FF_MAYBE_UNUSED static const char* ffAdlStatusToString(int status) {
