@@ -1,14 +1,22 @@
 extern "C" {
     #include "sound.h"
-    #include "util/windows/unicode.h"
+    #include "common/windows/unicode.h"
 }
-#include "util/windows/com.hpp"
+#include "common/windows/com.hpp"
 
 #include <initguid.h>
 #include <mmdeviceapi.h>
 #include <endpointvolume.h>
 #include <functiondiscoverykeys_devpkey.h>
 
+static void ffCoTaskMemFreeWrapper(void* pptr)
+{
+    assert(pptr != NULL);
+    void* ptr = *(void**)pptr;
+    if (ptr) CoTaskMemFree(ptr);
+}
+#define FF_COTASK_AUTO_FREE __attribute__((__cleanup__(ffCoTaskMemFreeWrapper)))
+
 const char* ffDetectSound(FFlist* devices /* List of FFSoundDevice */)
 {
     const char* error = ffInitCom();
@@ -20,7 +28,7 @@ const char* ffDetectSound(FFlist* devices /* List of FFSoundDevice */)
     if (FAILED(CoCreateInstance(CLSID_MMDeviceEnumerator, NULL, CLSCTX_ALL, IID_IMMDeviceEnumerator, (void **)&pEnum)))
         return "CoCreateInstance(CLSID_MMDeviceEnumerator) failed";
 
-    LPWSTR mainDeviceId = NULL;
+    LPWSTR FF_COTASK_AUTO_FREE mainDeviceId = NULL;
 
     {
         IMMDevice* FF_AUTO_RELEASE_COM_OBJECT pDefaultDevice = NULL;
@@ -47,7 +55,7 @@ const char* ffDetectSound(FFlist* devices /* List of FFSoundDevice */)
         if (FAILED(pDevices->Item(deviceIdx, &immDevice)))
             continue;
 
-        LPWSTR immDeviceId = NULL;
+        LPWSTR FF_COTASK_AUTO_FREE immDeviceId = NULL;
         if (FAILED(immDevice->GetId(&immDeviceId)))
             continue;
 
@@ -65,6 +73,7 @@ const char* ffDetectSound(FFlist* devices /* List of FFSoundDevice */)
         device->volume = FF_SOUND_VOLUME_UNKNOWN;
         ffStrbufInitWS(&device->identifier, immDeviceId);
         ffStrbufInit(&device->name);
+        ffStrbufInitStatic(&device->platformApi, "Core Audio APIs");
 
         {
             PROPVARIANT __attribute__((__cleanup__(PropVariantClear))) friendlyName;
