@@ -1,8 +1,8 @@
 #include "common/printing.h"
 #include "common/jsonconfig.h"
+#include "common/stringUtils.h"
 #include "detection/processes/processes.h"
 #include "modules/processes/processes.h"
-#include "util/stringUtils.h"
 
 bool ffPrintProcesses(FFProcessesOptions* options)
 {
